==> ejc-bfyjerp-impl-3.0.0-20250717.075627-240-sources.jar: com/ejianc/business/bid/bean/TenderFundsBackEntity.java <==
package com.ejianc.business.bid.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 投标管理-投标保证金退还
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_tender_funds_back")
public class TenderFundsBackEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 编码
    @TableField(value="tender_funds_id")
    private Long tenderFundsId; // 保证金申请Id
    @TableField(value = "tender_funds_bill_code")
    private String tenderFundsBillCode; //保证金申请单编号
    @TableField(value="registration_id")
    private Long registrationId; // 项目报名表Id
    @TableField(value="opportunity_id")
    private Long opportunityId; // 商机登记表Id
    @TableField(value="opportunity_bill_code")
    private Long opportunityBillCode; // 商机登记单据编码
    @TableField(value="engineering_name")
    private String engineeringName; // 工程名称
    @TableField(value="back_acc_name")
    private String backAccName; // 退还户名
    @TableField(value="back_acc_id")
    private Long backAccId; // 收款账户
    @TableField(value="back_acc")
    private String backAcc; // 退还账号
    @TableField(value="mny")
    private BigDecimal mny; // 金额
    @TableField(value="employee_id")
    private Long employeeId; // 编制人id
    @TableField(value="employee_name")
    private String employeeName; // 编制人名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="commit_date")
    private Date commitDate; // 提交日期
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名称
    @TableField(value="commit_user_code")
    private String commitUserCode; // 提交人账号
    @TableField(value="effective_date")
    private Date effectiveDate; // 生效日期

    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_code")
    private String orgCode; // 所属组织编码
    @TableField(value="org_name")
    private String orgName; // 所属组织名称


    @TableField(value="account_register_id")
    private Long accountRegisterId; // 公司付款账户
    @TableField(value="account_name")
    private String accountName; // 公司付款账户名称
    @TableField(value="account_num")
    private String accountNum; // 公司付款银行账号
    @TableField(value="account_bank")
    private String accountBank; // 公司付款开户行
    @TableField("back_mny")
    private BigDecimal backMny; // 返还金额

    public Long getBackAccId() {
        return backAccId;
    }

    public void setBackAccId(Long backAccId) {
        this.backAccId = backAccId;
    }

    public Long getAccountRegisterId() {
        return accountRegisterId;
    }

    public void setAccountRegisterId(Long accountRegisterId) {
        this.accountRegisterId = accountRegisterId;
    }

    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }

    public String getAccountNum() {
        return accountNum;
    }

    public void setAccountNum(String accountNum) {
        this.accountNum = accountNum;
    }

    public String getAccountBank() {
        return accountBank;
    }

    public void setAccountBank(String accountBank) {
        this.accountBank = accountBank;
    }

    public BigDecimal getBackMny() {
        return backMny;
    }

    public void setBackMny(BigDecimal backMny) {
        this.backMny = backMny;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getTenderFundsBillCode() {
        return tenderFundsBillCode;
    }

    public void setTenderFundsBillCode(String tenderFundsBillCode) {
        this.tenderFundsBillCode = tenderFundsBillCode;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getRegistrationId() {
        return registrationId;
    }

    public void setRegistrationId(Long registrationId) {
        this.registrationId = registrationId;
    }
    public Long getOpportunityId() {
        return opportunityId;
    }

    public void setOpportunityId(Long opportunityId) {
        this.opportunityId = opportunityId;
    }
    public Long getOpportunityBillCode() {
        return opportunityBillCode;
    }

    public void setOpportunityBillCode(Long opportunityBillCode) {
        this.opportunityBillCode = opportunityBillCode;
    }
    public String getEngineeringName() {
        return engineeringName;
    }

    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }
    public Long getTenderFundsId() {
        return tenderFundsId;
    }

    public void setTenderFundsId(Long tenderFundsId) {
        this.tenderFundsId = tenderFundsId;
    }
    public String getBackAccName() {
        return backAccName;
    }

    public void setBackAccName(String backAccName) {
        this.backAccName = backAccName;
    }
    public String getBackAcc() {
        return backAcc;
    }

    public void setBackAcc(String backAcc) {
        this.backAcc = backAcc;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    
}

==> ejc-bfyjerp-impl-3.0.0-20250822.082441-284-sources.jar: com/ejianc/business/bid/bean/TenderFundsBackEntity.java <==
package com.ejianc.business.bid.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 投标管理-投标保证金退还
 * 
 * @author generator
 * 
 */
 @TableName("ejc_bid_tender_funds_back")
public class TenderFundsBackEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 编码
    @TableField(value="tender_funds_id")
    private Long tenderFundsId; // 保证金申请Id
    @TableField(value = "tender_funds_bill_code")
    private String tenderFundsBillCode; //保证金申请单编号
    @TableField(value="registration_id")
    private Long registrationId; // 项目报名表Id
    @TableField(value="opportunity_id")
    private Long opportunityId; // 商机登记表Id
    @TableField(value="opportunity_bill_code")
    private Long opportunityBillCode; // 商机登记单据编码
    @TableField(value="engineering_name")
    private String engineeringName; // 工程名称
    @TableField(value="back_acc_name")
    private String backAccName; // 退还户名
    @TableField(value="back_acc_id")
    private Long backAccId; // 收款账户
    @TableField(value="back_acc")
    private String backAcc; // 退还账号
    @TableField(value="mny")
    private BigDecimal mny; // 金额
    @TableField(value="employee_id")
    private Long employeeId; // 编制人id
    @TableField(value="employee_name")
    private String employeeName; // 编制人名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="commit_date")
    private Date commitDate; // 提交日期
    @TableField(value="commit_user_name")
    private String commitUserName; // 提交人名称
    @TableField(value="commit_user_code")
    private String commitUserCode; // 提交人账号
    @TableField(value="effective_date")
    private Date effectiveDate; // 生效日期

    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_code")
    private String orgCode; // 所属组织编码
    @TableField(value="org_name")
    private String orgName; // 所属组织名称


    @TableField(value="account_register_id")
    private Long accountRegisterId; // 公司付款账户
    @TableField(value="account_name")
    private String accountName; // 公司付款账户名称
    @TableField(value="account_num")
    private String accountNum; // 公司付款银行账号
    @TableField(value="account_bank")
    private String accountBank; // 公司付款开户行
    @TableField("back_mny")
    private BigDecimal backMny; // 返还金额
    @TableField("fee_type")
    private String feeType; // 费用类型

    public String getFeeType() {
        return feeType;
    }

    public void setFeeType(String feeType) {
        this.feeType = feeType;
    }
    public Long getBackAccId() {
        return backAccId;
    }

    public void setBackAccId(Long backAccId) {
        this.backAccId = backAccId;
    }

    public Long getAccountRegisterId() {
        return accountRegisterId;
    }

    public void setAccountRegisterId(Long accountRegisterId) {
        this.accountRegisterId = accountRegisterId;
    }

    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }

    public String getAccountNum() {
        return accountNum;
    }

    public void setAccountNum(String accountNum) {
        this.accountNum = accountNum;
    }

    public String getAccountBank() {
        return accountBank;
    }

    public void setAccountBank(String accountBank) {
        this.accountBank = accountBank;
    }

    public BigDecimal getBackMny() {
        return backMny;
    }

    public void setBackMny(BigDecimal backMny) {
        this.backMny = backMny;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getTenderFundsBillCode() {
        return tenderFundsBillCode;
    }

    public void setTenderFundsBillCode(String tenderFundsBillCode) {
        this.tenderFundsBillCode = tenderFundsBillCode;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getRegistrationId() {
        return registrationId;
    }

    public void setRegistrationId(Long registrationId) {
        this.registrationId = registrationId;
    }
    public Long getOpportunityId() {
        return opportunityId;
    }

    public void setOpportunityId(Long opportunityId) {
        this.opportunityId = opportunityId;
    }
    public Long getOpportunityBillCode() {
        return opportunityBillCode;
    }

    public void setOpportunityBillCode(Long opportunityBillCode) {
        this.opportunityBillCode = opportunityBillCode;
    }
    public String getEngineeringName() {
        return engineeringName;
    }

    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }
    public Long getTenderFundsId() {
        return tenderFundsId;
    }

    public void setTenderFundsId(Long tenderFundsId) {
        this.tenderFundsId = tenderFundsId;
    }
    public String getBackAccName() {
        return backAccName;
    }

    public void setBackAccName(String backAccName) {
        this.backAccName = backAccName;
    }
    public String getBackAcc() {
        return backAcc;
    }

    public void setBackAcc(String backAcc) {
        this.backAcc = backAcc;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    
}
